bluesky
=======

[![Build Status](https://travis-ci.org/NSLS-II/bluesky.svg)](https://travis-ci.org/NSLS-II/bluesky)

a Python data collection interface for experimental science

See [documentation](http://nsls-ii.github.io/bluesky).

[Report an issue with bluesky](https://github.com/NSLS-II/bluesky/issues/new)

## Conda Recipes

Install the most recent tagged build: `conda install bluesky -c lightsource2-tag`

Install the most recent development build: `conda install bluesky -c lightsource2-dev`

Find the tagged recipe [here](https://github.com/NSLS-II/lightsource2-recipes/tree/master/recipes-tag/bluesky) and the dev recipe [here](https://github.com/NSLS-II/lightsource2-recipes/tree/master/recipes-dev/bluesky)
